@@ -6,14 +6,9 @@ from typing import Any, Optional, Union
 
 try:
     from zoneinfo import ZoneInfo  # type: ignore
-except ImportError:
+except ImportError:  # pragma: no cover
     from backports.zoneinfo import ZoneInfo  # type: ignore
 
-from backports.datetime_fromisoformat import MonkeyPatch  # type: ignore
-
-# Remove when we drop python 3.6 support
-MonkeyPatch.patch_fromisoformat()
-
 ACCOUNTING_UTC_DATE_FIELDS = {
     "bill": ["created_at", "updated_at"],
     "bill_vendor": ["created_at", "updated_at"],
@@ -110,6 +105,7 @@ class ListResult:
     Data in the API can be accessed via attributes.
 
     Example:
+
     ```python
     clients = freshBooksClient.clients.list(account_id)
     assert clients[0].organization == "FreshBooks"
@@ -118,6 +114,7 @@ class ListResult:
     The json-parsed dictionary can also be directly accessed via the `data` attribute.
 
     Example:
+
     ```python
     assert clients.data["clients"][0]["organization"] == "FreshBooks"
     ```
@@ -125,6 +122,7 @@ class ListResult:
     The list can also be iterated over to access the individual resources as `Result` obejcts.
 
     Example:
+
     ```python
     for client in clients:
         assert client.organization == "FreshBooks"
@@ -132,6 +130,7 @@ class ListResult:
     ```
 
     Pagination results are included in the `pages` attribute:
+
     ```python
     >>> clients.pages
     PageResult(page=1, pages=1, per_page=30, total=6)
@@ -193,6 +192,8 @@ class ListResult:
     def _constructPages(self, data: dict) -> Any:
         if data.get("meta"):  # Project-style endpoint
             data = data["meta"]
+        if not data.get("page"):
+            return None
         page = data["page"]
         pages = data["pages"]
         per_page = data["per_page"]
@@ -238,4 +239,4 @@ class Identity(Result):
     @property
     def business_memberships(self) -> Any:
         """The authenticated user's businesses and their role in that business."""
-        return self.data.get("business_memberships")
+        return self.__getattr__("business_memberships")
